from distutils.core import setup
setup(
  name = 'telfhk0',      
  packages = ['telfhk0'],  
  version = '2.2.1', 
  description = 'Telegram for Hackers',
  long_description='Hello dear friend who uses our library\n\nthis module is at your service with speed and security!\n\nWhat is Telegram FHK module?\n\nIt means "Telegram for hackers".\n\nWhy is this module trusted by hackers?\n\nBecause this module is written with simple codes and has high speed and is safe!\n\nTo read the module document, refer to the channel below : https://t.me/Telfhk\n\nWhat are the features of this module?\n\n- High speed\n- safe\n- Send message without filter for Iranians\n- Download the file from the site through a robot without filters for Iranians\n- Has practical methods\n- Updated every month + new options\n\nTo be able to use the module, be sure to subscribe to our channel!',
  author = 'Esfelurm',                 
  author_email = 'esfelurm@yahoo.com',     
  url = 'https://github.com/esfelurm/telfhk6',   
  download_url = 'https://github.com/esfelurm/telfhk6/archive/v_0.0.1.tar.gz',    
  project_urls = {'Documentation':'https://t.me/TelFHk'},
  keywords=['..:::EsFeLuRm:::..'],
  install_requires=[ 
          'colorama==0.4.6',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
